pub enum CompareMode {
TwoUp,
Swipe,
Onion,
Difference,
Left,
Right,
}Expand description
One of the ways the two images can be compared.
Variants
Implementations
Sourceimpl CompareMode
impl CompareMode
Sourcepub const ALL: [CompareMode; 6]
pub const ALL: [CompareMode; 6]
The comparison modes offered in the control bar, left to right. The
single-image views (Left/Right) come last.
Sourcepub fn next(self) -> Self
pub fn next(self) -> Self
Cycle to the next comparison mode (the View ▸ Switch Mode action). The single-image views are skipped — they cycle back to 2-Up.
Sourcepub fn uses_slider(self) -> bool
pub fn uses_slider(self) -> bool
Whether this mode is steered by the 0..1 slider.